@@ -31,16 +31,20 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfce4panel/xfce-panel-convenience.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
-#include <libxfce4panel/xfce-hvbox.h>
 
 #include "wi.h"
 
 #include <string.h>
 #include <ctype.h>
 
+#ifdef LIBXFCE4PANEL_CHECK_VERSION
+#if LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+#define HAS_PANEL_49
+#endif
+#endif
+
 #define BORDER 8
 typedef struct
 {
@@ -73,7 +77,6 @@ wavelan_set_state(t_wavelan *wavelan, gint state)
   /* state = 0 -> no link, =-1 -> error */
   TRACE ("Entered wavelan_set_state, state = %u", state);
 
-  GtkRcStyle *rc = NULL;
   GdkColor color;
 
   gchar signal_color_bad[] = "#e00000";
@@ -91,10 +94,6 @@ wavelan_set_state(t_wavelan *wavelan, gint state)
 
    if (wavelan->signal_colors) {
     /* set color */
-    rc = gtk_widget_get_modifier_style(GTK_WIDGET(wavelan->signal));
-    if (rc) {
-     rc->color_flags[GTK_STATE_PRELIGHT] |= GTK_RC_BG;
-     rc->color_flags[GTK_STATE_SELECTED] |= GTK_RC_BASE;
      if (state > 70)
       gdk_color_parse(signal_color_strong, &color);
      else if (state > 55)
@@ -103,15 +102,16 @@ wavelan_set_state(t_wavelan *wavelan, gint state)
       gdk_color_parse(signal_color_weak, &color);
      else
       gdk_color_parse(signal_color_bad, &color);
-     rc->bg[GTK_STATE_PRELIGHT] = color;
-     rc->base[GTK_STATE_SELECTED] = color;
-     gtk_widget_modify_style(GTK_WIDGET(wavelan->signal), rc);
-     }
-    }
-   else {
-    rc = gtk_rc_style_new();
-    gtk_widget_modify_style(GTK_WIDGET(wavelan->signal), rc);
-    g_object_unref(rc);
+
+        gtk_widget_modify_bg(GTK_WIDGET(wavelan->signal),
+                             GTK_STATE_PRELIGHT,
+                             &color);
+        gtk_widget_modify_bg(GTK_WIDGET(wavelan->signal),
+                             GTK_STATE_SELECTED,
+                             &color);
+        gtk_widget_modify_base(GTK_WIDGET(wavelan->signal),
+                             GTK_STATE_SELECTED,
+                             &color);
     }
 
    }
@@ -333,7 +333,11 @@ wavelan_new(XfcePanelPlugin *plugin)
   }
 
   wavelan->image = gtk_image_new();
+#ifdef HAS_PANEL_49
+  gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size/xfce_panel_plugin_get_nrows(wavelan->plugin)-6, 0, NULL));
+#else
   gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size-6, 0, NULL));
+#endif
 
   gtk_box_pack_start(GTK_BOX(wavelan->box), GTK_WIDGET(wavelan->image), FALSE, FALSE, 2);
   gtk_box_pack_start(GTK_BOX(wavelan->box), GTK_WIDGET(wavelan->signal), FALSE, FALSE, 2);
@@ -426,7 +430,11 @@ static void
 wavelan_set_size(t_wavelan *wavelan, int size)
 {
   wavelan->size = size;
+#ifdef HAS_PANEL_49
+  gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size/xfce_panel_plugin_get_nrows(wavelan->plugin)-6, 0, NULL));
+#else
   gtk_image_set_from_pixbuf(GTK_IMAGE(wavelan->image), gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), "network-wireless", wavelan->size-6, 0, NULL));
+#endif
   if (wavelan->orientation == GTK_ORIENTATION_HORIZONTAL)
    gtk_widget_set_size_request(wavelan->ebox, -1, wavelan->size);
   else
@@ -485,34 +493,28 @@ static void
 wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
 {
   GtkWidget *dlg, *hbox, *label, *interface, *vbox, *autohide;
-  GtkWidget *autohide_missing, *header, *warn_label, *signal_colors;
+  GtkWidget *autohide_missing, *warn_label, *signal_colors;
   GtkWidget *combo;
   GList     *interfaces, *lp;
 
   TRACE ("Entered wavelan_create_options");
   
-  dlg = gtk_dialog_new_with_buttons (_("Properties"),
-              GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-              GTK_DIALOG_DESTROY_WITH_PARENT | 
+  dlg = xfce_titled_dialog_new_with_buttons (_("Wavelan Plugin Options"),
+              NULL,
               GTK_DIALOG_NO_SEPARATOR,
-              GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+              GTK_STOCK_CLOSE,
+              GTK_RESPONSE_OK,
               NULL);
 
-  g_object_set_data (G_OBJECT (plugin), "dialog", dlg);
-
   gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
+  gtk_window_set_icon_name (GTK_WINDOW (dlg), "network-wireless");
 
   g_signal_connect (dlg, "response", G_CALLBACK (wavelan_dialog_response),
                     wavelan);
   
   gtk_container_set_border_width (GTK_CONTAINER (dlg), 2);
 
-  header = xfce_create_header (NULL, _("Wavelan Plugin Options"));
-  gtk_widget_set_size_request (GTK_BIN (header)->child, 200, 32);
-  gtk_container_set_border_width (GTK_CONTAINER (header), 6);
-  gtk_widget_show (header);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), header,
-                      FALSE, TRUE, 0);
+  xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Properties"));
               
   vbox = gtk_vbox_new(FALSE, 8);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
@@ -625,6 +627,26 @@ wavelan_configure (XfcePanelPlugin *plugin, t_wavelan *wavelan)
     wavelan_create_options(plugin, wavelan);
 }
 
+static void
+wavelan_show_about (XfcePanelPlugin *plugin, t_wavelan *wavelan)
+{
+   GdkPixbuf *icon;
+   const gchar *auth[] = { "Benedikt Meurer <benny at xfce.org>", "Florian Rivoal <frivoal@xfce.org>", NULL };
+   icon = xfce_panel_pixbuf_from_source("network-wireless", NULL, 32);
+   gtk_show_about_dialog(NULL,
+      "logo", icon,
+      "license", xfce_get_license_text (XFCE_LICENSE_TEXT_BSD),
+      "version", PACKAGE_VERSION,
+      "program-name", PACKAGE_NAME,
+      "comments", _("View the status of a wireless network"),
+      "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-wavelan-plugin",
+      "copyright", "Copyright (c) 2003-2004 Benedikt Meurer\n",
+      "authors", auth, NULL);
+
+   if(icon)
+      g_object_unref(G_OBJECT(icon));
+}
+
 static void
 wavelan_construct (XfcePanelPlugin *plugin)
 {
@@ -654,6 +676,8 @@ wavelan_construct (XfcePanelPlugin *plugin)
   g_signal_connect (plugin, "configure-plugin",
                     G_CALLBACK (wavelan_configure), wavelan);
   
+  xfce_panel_plugin_menu_show_about(plugin);
+  g_signal_connect (plugin, "about", G_CALLBACK (wavelan_show_about), wavelan);
 }
 
 #if 0
@@ -673,5 +697,5 @@ int main(int argc, char** argv)
 	return 0;
 }
 #else
-XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL(wavelan_construct);
+XFCE_PANEL_PLUGIN_REGISTER(wavelan_construct);
 #endif
